summaryrefslogtreecommitdiffstats
path: root/third_party/aom/test/av1_ext_tile_test.cc
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/aom/test/av1_ext_tile_test.cc')
-rw-r--r--third_party/aom/test/av1_ext_tile_test.cc16
1 files changed, 11 insertions, 5 deletions
diff --git a/third_party/aom/test/av1_ext_tile_test.cc b/third_party/aom/test/av1_ext_tile_test.cc
index f96447965..034b07167 100644
--- a/third_party/aom/test/av1_ext_tile_test.cc
+++ b/third_party/aom/test/av1_ext_tile_test.cc
@@ -30,11 +30,11 @@ const int kTIleSizeInPixels = (kTileSize << 6);
const int kImgWidth = 704;
const int kImgHeight = 576;
// This test tests "tile_encoding_mode = TILE_VR" case. The TILE_NORMAL case is
// tested by the tile_independence test.
class AV1ExtTileTest
- : public ::libaom_test::EncoderTest,
- public ::libaom_test::CodecTestWith2Params<libaom_test::TestMode, int> {
+ : public ::libaom_test::CodecTestWith2Params<libaom_test::TestMode, int>,
+ public ::libaom_test::EncoderTest {
protected:
AV1ExtTileTest()
: EncoderTest(GET_PARAM(0)), encoding_mode_(GET_PARAM(1)),
@@ -43,6 +43,7 @@ class AV1ExtTileTest
aom_codec_dec_cfg_t cfg = aom_codec_dec_cfg_t();
cfg.w = kImgWidth;
cfg.h = kImgHeight;
+ cfg.allow_lowbitdepth = 1;
decoder_ = codec_->CreateDecoder(cfg, 0);
decoder_->Control(AV1_SET_DECODE_TILE_ROW, -1);
@@ -83,11 +84,15 @@ class AV1ExtTileTest
// The tile size is 64x64.
encoder->Control(AV1E_SET_TILE_COLUMNS, kTileSize);
encoder->Control(AV1E_SET_TILE_ROWS, kTileSize);
- encoder->Control(AV1E_SET_TILE_ENCODING_MODE, 1); // TILE_VR
+ // TODO(yunqingwang): test single_tile_decoding = 0.
+ encoder->Control(AV1E_SET_SINGLE_TILE_DECODING, 1);
#if CONFIG_EXT_PARTITION
// Always use 64x64 max partition.
encoder->Control(AV1E_SET_SUPERBLOCK_SIZE, AOM_SUPERBLOCK_SIZE_64X64);
#endif
+#if CONFIG_LOOPFILTERING_ACROSS_TILES
+ encoder->Control(AV1E_SET_TILE_LOOPFILTER, 0);
+#endif
}
if (video->frame() == 1) {
@@ -182,6 +187,7 @@ TEST_P(AV1ExtTileTest, DecoderResultTest) {
kImgHeight, 30, 1, 0, kLimit);
cfg_.rc_target_bitrate = 500;
cfg_.g_error_resilient = AOM_ERROR_RESILIENT_DEFAULT;
+ cfg_.large_scale_tile = 1;
cfg_.g_lag_in_frames = 0;
cfg_.g_threads = 1;
@@ -30,11 +30,11 @@ const int kTIleSizeInPixels = (kTileSize << 6);
const int kImgWidth = 704;
const int kImgHeight = 576;
-// This test tests "tile_encoding_mode = TILE_VR" case. The TILE_NORMAL case is
-// tested by the tile_independence test.
+// This test tests large scale tile coding case. Non-large-scale tile coding
+// is tested by the tile_independence test.
class AV1ExtTileTest